==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
var ChaikinOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChaikinOscillatorIndicatorDescriptionMetadata, _super);
    function ChaikinOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
            ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.d = function (a) {
        ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("ChaikinOscillatorIndicator", function () { return new ChaikinOscillatorIndicatorDescription(); });
        a.z("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
}(Base));
export { ChaikinOscillatorIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
var ChaikinOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChaikinOscillatorIndicatorDescriptionMetadata, _super);
    function ChaikinOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
            ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.k(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.d = function (a) {
        ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
        a.ac("ChaikinOscillatorIndicator", function () { return new ChaikinOscillatorIndicatorDescription(); });
        a.ab("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
}(Base));
export { ChaikinOscillatorIndicatorDescriptionMetadata };
